@@ -83,6 +83,7 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config,
         KConfigGroup baloorcGroup = baloorc.group("Akonadi");
         initialIndexingDone = baloorcGroup.readEntry("initialIndexingDone", false);
         cfg.writeEntry("initialIndexingDone", initialIndexingDone);
+        baloorcGroup.deleteEntry("initialIndexingDone"); // make sure that editing akonadi_indexing_agentrc by hand works in the future
     }
     //Trigger a full sync initially
     if (!initialIndexingDone) {
@@ -195,7 +196,7 @@ void Scheduler::slotRootCollectionsFetched(KJob *kjob)
     // If we did not schedule any collection
     if (m_collectionQueue.isEmpty()) {
         qCDebug(AKONADI_INDEXER_AGENT_LOG) << "No collections scheduled";
-        status(Akonadi::AgentBase::Idle, i18n("Ready"));
+        Q_EMIT status(Akonadi::AgentBase::Idle, i18n("Ready"));
     }
 }
 
@@ -227,7 +228,7 @@ void Scheduler::abort()
     m_currentJob = nullptr;
     collectDirtyCollections();
     m_collectionQueue.clear();
-    status(Akonadi::AgentBase::Idle, i18n("Ready"));
+    Q_EMIT status(Akonadi::AgentBase::Idle, i18n("Ready"));
 }
 
 void Scheduler::processNext()
@@ -238,7 +239,7 @@ void Scheduler::processNext()
     }
     if (m_collectionQueue.isEmpty()) {
         qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Processing done";
-        status(Akonadi::AgentBase::Idle, i18n("Ready"));
+        Q_EMIT status(Akonadi::AgentBase::Idle, i18n("Ready"));
         return;
     }
 
@@ -271,7 +272,8 @@ void Scheduler::slotIndexingFinished(KJob *job)
     } else {
         const Akonadi::Collection::Id collectionId = job->property("collection").value<Akonadi::Collection::Id>();
         m_dirtyCollections.remove(collectionId);
-        status(Akonadi::AgentBase::Idle, i18n("Collection \"%1\" indexed", collectionId));
+        Q_EMIT status(Akonadi::AgentBase::Idle, i18n("Collection \"%1\" indexed", collectionId));
+        Q_EMIT collectionIndexingFinished(collectionId);
     }
     m_currentJob = nullptr;
     m_processTimer.start();
