@@ -21,6 +21,8 @@
  */
 
 #include "searchstore.h"
+#include "akonadi_search_core_debug.h"
+#include "helper_p.h"
 
 #include <QDebug>
 #include <QThreadStorage>
@@ -69,7 +71,7 @@ void SearchStore::overrideSearchStores(const QList<SearchStore *> &overrideSearc
     list->clear();
     list->reserve(overrideSearchStores.count());
 
-    Q_FOREACH (SearchStore *store, overrideSearchStores) {
+    for (SearchStore *store : overrideSearchStores) {
         list->append(QSharedPointer<SearchStore>(store));
     }
 }
@@ -84,7 +86,7 @@ SearchStore::List SearchStore::searchStores()
     QMutexLocker lock(&mutex);
 
     if (s_overrideSearchStores && !s_overrideSearchStores->isEmpty()) {
-        qDebug() << "Overriding search stores.";
+        qCDebug(AKONADI_SEARCH_CORE_LOG) << "Overriding search stores.";
         return *s_overrideSearchStores;
     }
 
@@ -92,8 +94,8 @@ SearchStore::List SearchStore::searchStores()
     QStringList plugins;
     QStringList pluginPaths;
 
-    QStringList paths = QCoreApplication::libraryPaths();
-    Q_FOREACH (const QString &libraryPath, paths) {
+    const QStringList paths = QCoreApplication::libraryPaths();
+    for (const QString &libraryPath : paths) {
         QString path(libraryPath + QStringLiteral("/akonadi"));
         QDir dir(path);
 
@@ -101,8 +103,8 @@ SearchStore::List SearchStore::searchStores()
             continue;
         }
 
-        QStringList entryList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
-        Q_FOREACH (const QString &fileName, entryList) {
+        const QStringList entryList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+        for (const QString &fileName : entryList) {
             if (plugins.contains(fileName)) {
                 continue;
             }
@@ -114,7 +116,7 @@ SearchStore::List SearchStore::searchStores()
     plugins.clear();
 
     SearchStore::List stores;
-    Q_FOREACH (const QString &pluginPath, pluginPaths) {
+    for (const QString &pluginPath : qAsConst(pluginPaths)) {
         QPluginLoader loader(pluginPath);
 
         const QVariantMap metadata = loader.metaData().toVariantMap()[QStringLiteral("MetaData")].toMap();
@@ -123,8 +125,8 @@ SearchStore::List SearchStore::searchStores()
         }
 
         if (!loader.load()) {
-            qWarning() << "Could not create Akonadi Search Store: " << pluginPath;
-            qWarning() << loader.errorString();
+            qCWarning(AKONADI_SEARCH_CORE_LOG) << "Could not create Akonadi Search Store: " << pluginPath;
+            qCWarning(AKONADI_SEARCH_CORE_LOG) << loader.errorString();
             continue;
         }
 
@@ -134,11 +136,10 @@ SearchStore::List SearchStore::searchStores()
             if (ex) {
                 stores << QSharedPointer<SearchStore>(ex);
             } else {
-                qDebug() << "Plugin could not be converted to an Akonadi::Search::SearchStore";
-                qDebug() << pluginPath;
+                qCDebug(AKONADI_SEARCH_CORE_LOG) << "Plugin could not be converted to an Akonadi::Search::SearchStore " << pluginPath;
             }
         } else {
-            qDebug() << "Plugin could not create instance" << pluginPath;
+            qCDebug(AKONADI_SEARCH_CORE_LOG) << "Plugin could not create instance" << pluginPath;
         }
     }
 
