@@ -21,6 +21,7 @@
  */
 
 #include "term.h"
+#include "helper_p.h"
 #include <QVariant>
 #include <QDateTime>
 
@@ -245,7 +246,7 @@ QVariantMap Term::toVariantMap() const
     if (d->m_op != None) {
         QVariantList variantList;
         variantList.reserve(d->m_subTerms.count());
-        Q_FOREACH (const Term &term, d->m_subTerms) {
+        for (const Term &term : qAsConst(d->m_subTerms)) {
             variantList << QVariant(term.toVariantMap());
         }
 
@@ -307,7 +308,7 @@ QVariant tryConvert(const QVariant &var)
             return var;
         }
 
-        if (!var.toString().contains(QStringLiteral("T"))) {
+        if (!var.toString().contains(QLatin1Char('T'))) {
             return QVariant(var.toDate());
         }
         return dt;
@@ -336,9 +337,9 @@ Term Term::fromVariantMap(const QVariantMap &map)
     if (andOrString.size()) {
         QList<Term> subTerms;
 
-        QVariantList list = map[andOrString].toList();
+        const QVariantList list = map[andOrString].toList();
         subTerms.reserve(list.count());
-        Q_FOREACH (const QVariant &var, list) {
+        for (const QVariant &var : list) {
             subTerms << Term::fromVariantMap(var.toMap());
         }
 
@@ -400,7 +401,7 @@ bool Term::operator==(const Term &rhs) const
         return true;
     }
 
-    Q_FOREACH (const Term &t, d->m_subTerms) {
+    for (const Term &t : qAsConst(d->m_subTerms)) {
         if (!rhs.d->m_subTerms.contains(t)) {
             return false;
         }
@@ -464,7 +465,7 @@ QDebug operator <<(QDebug d, const Term &t)
     } else {
         d << "(" << operationToString(t.operation()).toUtf8().constData();
         const QList<Term> subterms = t.subTerms();
-        Q_FOREACH (const Term &term, subterms) {
+        for (const Term &term : qAsConst(subterms)) {
             d << term;
         }
         d << ")";
