@@ -97,7 +97,7 @@ void App::main()
 
 void App::itemsReceived(const Akonadi::Item::List &itemList)
 {
-    Q_FOREACH (const Akonadi::Item &item, itemList) {
+    for (const Akonadi::Item &item : itemList) {
         KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
         QDateTime date = message->date()->dateTime();
         qDebug() << date.toString(Qt::ISODate) << message->subject()->asUnicodeString();
