@@ -28,16 +28,16 @@ class PIMContactsRunnerConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit PIMContactsRunnerConfig(QWidget *parent = Q_NULLPTR,
+    explicit PIMContactsRunnerConfig(QWidget *parent = nullptr,
                                      const QVariantList &args = QVariantList());
 
 public Q_SLOTS:
-    void save();
-    void load();
-    void defaults();
+    void save() Q_DECL_OVERRIDE;
+    void load() Q_DECL_OVERRIDE;
+    void defaults() Q_DECL_OVERRIDE;
 
 private:
     QCheckBox *mQueryCompletionCheckBox;
 };
 
-#endif
\ No newline at end of file
+#endif
